@@ -9,15 +9,15 @@ from vortex.Payload import Payload
 from vortex.PayloadEndpoint import PayloadEndpoint
 from vortex.PayloadEnvelope import PayloadEnvelope
 
-from peek_abstract_chunked_index.private.tuples.ACIEncodedChunkTupleABC import \
-    ACIEncodedChunkTupleABC
+from peek_abstract_chunked_index.private.tuples.ACIEncodedChunkTupleABC import (
+    ACIEncodedChunkTupleABC,
+)
 
-ChunkedIndexChunkLoadRpcMethodType = Callable[[int, int],
-                                              List[ACIEncodedChunkTupleABC]]
+ChunkedIndexChunkLoadRpcMethodType = Callable[[int, int], List[ACIEncodedChunkTupleABC]]
 
 
 class ACICacheControllerABC(metaclass=ABCMeta):
-    """ Chunked Index Cache Controller
+    """Chunked Index Cache Controller
 
     The Chunked Index cache controller stores all the chunks in memory,
     allowing fast access from the mobile and desktop devices.
@@ -44,8 +44,9 @@ class ACICacheControllerABC(metaclass=ABCMeta):
         #: This stores the cache of chunkedIndex data for the clients
         self._cache: Dict[int, ACIEncodedChunkTupleABC] = {}
 
-        self._endpoint = PayloadEndpoint(self._updateFromServerFilt,
-                                         self._processChunkedIndexPayload)
+        self._endpoint = PayloadEndpoint(
+            self._updateFromServerFilt, self._processChunkedIndexPayload
+        )
 
     def setCacheHandler(self, handler):
         self._webAppHandler = handler
@@ -63,12 +64,15 @@ class ACICacheControllerABC(metaclass=ABCMeta):
     @inlineCallbacks
     def reloadCache(self):
         startTime = datetime.now(pytz.utc)
-        yield DeferredList([self._reloadCacheThread(index)
-                            for index in range(self._LOAD_CHUNK_PARALLELISM)],
-                           fireOnOneErrback=True)
+        yield DeferredList(
+            [
+                self._reloadCacheThread(index)
+                for index in range(self._LOAD_CHUNK_PARALLELISM)
+            ],
+            fireOnOneErrback=True,
+        )
 
-        self._logger.info("Completed loading in %s",
-                          datetime.now(pytz.utc) - startTime)
+        self._logger.info("Completed loading in %s", datetime.now(pytz.utc) - startTime)
 
     @inlineCallbacks
     def _reloadCacheThread(self, threadIndex: int):
@@ -76,11 +80,13 @@ class ACICacheControllerABC(metaclass=ABCMeta):
 
         offset = self._LOAD_CHUNK_SIZE * threadIndex
         while True:
-            self._logger.info("Loading %s to %s"
-                              % (offset, offset + self._LOAD_CHUNK_SIZE))
+            self._logger.info(
+                "Loading %s to %s" % (offset, offset + self._LOAD_CHUNK_SIZE)
+            )
 
-            encodedPayload = \
-                yield self._chunkLoadRpcMethod(offset, self._LOAD_CHUNK_SIZE)
+            encodedPayload = yield self._chunkLoadRpcMethod(
+                offset, self._LOAD_CHUNK_SIZE
+            )
 
             if not encodedPayload:
                 break
@@ -111,16 +117,20 @@ class ACICacheControllerABC(metaclass=ABCMeta):
                     chunkKeysUpdated.append(t.ckiChunkKey)
                 continue
 
-            if (not t.ckiChunkKey in self._cache or
-                    self._cache[t.ckiChunkKey].ckiLastUpdate != t.ckiLastUpdate):
+            if (
+                not t.ckiChunkKey in self._cache
+                or self._cache[t.ckiChunkKey].ckiLastUpdate != t.ckiLastUpdate
+            ):
                 updatedCount += 1
                 self._cache[t.ckiChunkKey] = t
                 chunkKeysUpdated.append(t.ckiChunkKey)
 
-        self._logger.debug("Received %s updates from server"
-                           ", %s had changed"
-                           ", %s were deleted",
-                           len(encodedChunkTuples), updatedCount, deletedCount)
+        self._logger.debug(
+            "Received %s updates from server" ", %s had changed" ", %s were deleted",
+            len(encodedChunkTuples),
+            updatedCount,
+            deletedCount,
+        )
 
         self._notifyOfChunkKeysUpdated(chunkKeysUpdated)
 
